
rm(list = ls())

library(ggplot2)
library(extrafont)
library(scales)

source("multiplot.R")

loadfonts(device="win")

# VESP15051202

int <-read.csv('VESP15051202_in.csv', header=T)#, skip=14)
ext <-read.csv('VESP15051202_out.csv', header=T)#, skip=14)

int$Date.Time <- strptime(int$Date.Time, format="%m/%d/%y %I:%M:%S %p")
ext$Date.Time <- strptime(ext$Date.Time, format="%m/%d/%y %I:%M:%S %p")

int$Date.Time <- as.POSIXct(int$Date.Time)
ext$Date.Time <- as.POSIXct(ext$Date.Time)

#Include only timeframe when the iButton was in the nest
int <- int[int$Date.Time > "2015-05-10" & int$Date.Time < "2015-05-29",]
ext <- ext[ext$Date.Time > "2015-05-10" & ext$Date.Time < "2015-05-29",]

names(int)[names(int)=="Value"] <- "Temperature"
names(ext)[names(ext)=="Value"] <- "Temperature"


loc.a <- as.POSIXct(c("2015-05-10 00:01:00"))

plot.int <- ggplot(int, aes(x=Date.Time, y=Temperature, color=Temperature)) + 
  geom_point(alpha=0.7, size=1) +
  scale_y_continuous(limits = c(0, 47)) +
  scale_x_datetime(breaks=date_breaks("3 days"), minor_breaks=date_breaks("1 days"), labels=date_format("%b %d")) +
  scale_colour_gradient(high="darkred", limits=c(1.5,45)) +
  theme(text=element_text(family="Times New Roman", size=12)) +
  annotate("text", label="A", family="Times New Roman", x=loc.a, y=45, size=6)+
  #ggtitle("Nest iButton Temperature Data") +
  theme_bw() +
  theme(legend.position="none") +
  theme(plot.title=element_text(hjust=0.5, size=12)) +
#  theme(text=element_text(size=12)) +
  theme(axis.title.x=element_blank())

plot.int

plot.ext <- ggplot(ext, aes(x=Date.Time, y=Temperature, color=Temperature)) + 
  geom_point(alpha=0.5, size=1) +
  scale_y_continuous(limits = c(0, 47)) +
  scale_x_datetime(breaks=date_breaks("3 days"), minor_breaks=date_breaks("1 days"), labels=date_format("%b %d")) +
  scale_colour_gradient(high="darkred", limits=c(1.5,45)) +
  theme(text=element_text(family="Times New Roman", size=12)) +
  xlab("Time") +
  annotate("text", label="B", family="Times New Roman", x=loc.a, y=45, size=6) +
  #ggtitle("Environmental iButton Temperature Data") +
  theme_bw() +
  theme(legend.position="none") +
  theme(plot.title=element_text(hjust=0.5, size=12), axis.title.x=element_blank())

plot.ext

multiplot(plot.int, plot.ext, cols=1)
#ggsave("figure 1.png", device='png', width=6.25, height=3.75, plot=multiplot(plot.int, plot.ext, cols=1))



#### RWBL16052505
int <-read.csv('RWBL16052705_in.csv', header=T)#, skip=14)

int$Date.Time <- strptime(int$Date.Time, format="%m/%d/%y %I:%M:%S %p")
int$Date.Time <- as.POSIXct(int$Date.Time)

#Include only timeframe when the iButton was in the nest
int <- int[int$Date.Time > "2016-05-31" & int$Date.Time < "2016-06-26",]
row.names(int) <- 1:nrow(int)

names(int)[names(int)=="Value"] <- "Temperature"

plot.int <- ggplot(int, aes(x=Date.Time, y=Temperature, color=Temperature)) + 
  geom_point(alpha=0.7, size=1) +
  scale_y_continuous(limits = c(0, 47)) +
  scale_x_datetime(breaks=date_breaks("3 days"), minor_breaks=date_breaks("1 days"), labels=date_format("%b %d")) +
  scale_colour_gradient(high="darkred", limits=c(1.5,45)) +
  theme_bw() +
  theme(text=element_text(family="Times New Roman", size=12)) +
  #ggtitle("Nest iButton Temperature Data") +
  geom_vline(xintercept=as.numeric(int$Date.Time[25]), linetype="solid") +
  annotate("text", label="A", family="Times New Roman", size=4, x=int$Date.Time[36], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[66]), linetype="dashed") +
  annotate("text", label="3rd Egg Laid",family="Times New Roman", size=2.5, x=int$Date.Time[54], y=5.5, angle=90) + #3rd Egg laid
  annotate("text", label="Incubation Start",family="Times New Roman", size=2.5, x=int$Date.Time[76], y=7, angle=90) + #Incubation start 2016-06-02 12:54:00
  geom_vline(xintercept=as.numeric(int$Date.Time[106]), linetype="dashed") +
  annotate("text", label="4th Egg Laid",family="Times New Roman", size=2.5, x=int$Date.Time[116], y=5.5, angle=90) + #4th Egg
  geom_vline(xintercept=as.numeric(int$Date.Time[157]), linetype="solid") +
  annotate("text", label="B",family="Times New Roman", size=4, x=int$Date.Time[168], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[353]), linetype="solid") +
  annotate("text", label="C",family="Times New Roman", size=4, x=int$Date.Time[364], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[504]), linetype="solid") +
  annotate("text", label="D",family="Times New Roman", size=4, x=int$Date.Time[515], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[643]), linetype="dashed") +
  annotate("text", label="Inferred Hatch", family="Times New Roman", size=2.5, x=int$Date.Time[632], y=6.5, angle=90) + #Hatch 2016-06-12 04:24:00
  geom_vline(xintercept=as.numeric(int$Date.Time[652]), linetype="solid") +
  annotate("text", label="E",family="Times New Roman", size=4, x=int$Date.Time[663], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[843]), linetype="solid") +
  annotate("text", label="F",family="Times New Roman", size=4, x=int$Date.Time[854], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[988]), linetype="solid") +
  annotate("text", label="G",family="Times New Roman", size=4, x=int$Date.Time[999], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[1076]), linetype="dashed") +
  annotate("text", label="Nest Fails",family="Times New Roman", size=2.5, x=int$Date.Time[1063], y=4, angle=90) + #Nest failure
  geom_vline(xintercept=as.numeric(int$Date.Time[1213]), linetype="solid") +
  annotate("text", label="H",family="Times New Roman", size=4, x=int$Date.Time[1224], y=0) +
  geom_vline(xintercept=as.numeric(int$Date.Time[1206]), linetype="dashed") +
  annotate("text", label="Predicted Fledge",family="Times New Roman", size=2.5, x=int$Date.Time[1194], y=7.5, angle=90) + #Predicted Fledge
  theme(legend.position="none")+
  theme(plot.title=element_text(hjust=0.5), 
        text=element_text(size=12), 
        axis.title.x=element_blank())
plot.int

#ggsave("Figure 2.png", device='png', width=6.25, height=2.08)


