
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### This script creates the "Nests.fine.csv" and "Nests.course.csv" files ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

library(dplyr)

rm(list = ls())

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Creating seperate data files for coarse and fine scale data ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##


Nests <- read.csv("Nests.csv", header=T)

#Setting up data sets for iButton precision analysis
Nests <- Nests[Nests$iButton=="1",]
Nests <- Nests[Nests$field_season=="2015" | Nests$field_season=="2016",]

# Fine scale
Nests.f <- Nests

# Manual modifications
Nests.f <- Nests.f[Nests.f$nestID!=254,] #nestID 254 would have been "Not Revisited" if it weren't for iButton data and does not appear in coarse data

## Lost iButtons would have resulted in a loss of data
lost <- read.csv("lost ibutton corrections.csv", header=T)
lost$i_ibut_only <- as.numeric(as.Date(lost$i_ibut_only, format="%m/%d/%Y", origin = "1899-12-30"))
lost$j_ibut_only <- as.numeric(as.Date(lost$j_ibut_only, format="%m/%d/%Y", origin = "1899-12-30"))
lost$k_ibut_only <- as.numeric(as.Date(lost$k_ibut_only, format="%m/%d/%Y", origin = "1899-12-30"))

Apr1_2015 <- 16526
Apr1_2016 <- Apr1_2015 + 365

lost$i_ibut_only[lost$field_season==2015] <- lost$i_ibut_only[lost$field_season==2015] - Apr1_2015
lost$j_ibut_only[lost$field_season==2015] <- lost$j_ibut_only[lost$field_season==2015] - Apr1_2015
lost$k_ibut_only[lost$field_season==2015] <- lost$k_ibut_only[lost$field_season==2015] - Apr1_2015
lost$i_ibut_only[lost$field_season==2016] <- lost$i_ibut_only[lost$field_season==2016] - Apr1_2016
lost$j_ibut_only[lost$field_season==2016] <- lost$j_ibut_only[lost$field_season==2016] - Apr1_2016
lost$k_ibut_only[lost$field_season==2016] <- lost$k_ibut_only[lost$field_season==2016] - Apr1_2016


Nests.f$FirstFound.egg[match(lost$nestID, Nests.f$nestID)] <- lost$i_ibut_only
Nests.f$LastPresent.egg[match(lost$nestID, Nests.f$nestID)] <- lost$j_ibut_only
Nests.f$LastChecked.egg[match(lost$nestID, Nests.f$nestID)] <- lost$k_ibut_only

#write.csv(Nests.f, file = "Nests.fine.csv", row.names = F)



##~~~~~~~~~~~~~~~~~##
#### Coarse Data ####
##~~~~~~~~~~~~~~~~~##
Nests.c <- Nests
Nests.c <- subset(Nests.c, select=-c(FirstFound.egg,LastPresent.egg,LastChecked.egg,AgeDay1.egg,
                                     FirstFound.nest,LastPresent.nest,LastChecked.nest,AgeDay1.nest))


#Changing data types to numeric
Nests.c$date_discovered_i_egg_no_ibutton <- as.numeric(as.Date(Nests.c$date_discovered_i_egg_no_ibutton, format="%m/%d/%Y", origin = "1899-12-30"))
Nests.c$last_live_check_j_egg_no_ibutton <- as.numeric(as.Date(Nests.c$last_live_check_j_egg_no_ibutton, format="%m/%d/%Y", origin = "1899-12-30"))
Nests.c$last_check_k_egg_no_ibutton      <- as.numeric(as.Date(Nests.c$last_check_k_egg_no_ibutton, format="%m/%d/%Y", origin = "1899-12-30"))

# Adjusting discovery dates to day of nesting field_season

#Day 1 in 2015 was May 7th (16562)
#Apr 1st in 2015 was 16526
#Apr 1st in 2016 was
#Day 1 in 2016 was 16891

Apr1_2015 <- 16526
Apr1_2016 <- Apr1_2015 + 365

Nests.c$date_discovered_i_egg_no_ibutton[Nests.c$field_season==2015] <- Nests.c$date_discovered_i_egg_no_ibutton[Nests.c$field_season==2015] - Apr1_2015
Nests.c$last_live_check_j_egg_no_ibutton[Nests.c$field_season==2015] <- Nests.c$last_live_check_j_egg_no_ibutton[Nests.c$field_season==2015] - Apr1_2015
Nests.c$last_check_k_egg_no_ibutton[Nests.c$field_season==2015]      <- Nests.c$last_check_k_egg_no_ibutton[Nests.c$field_season==2015] - Apr1_2015

Nests.c$date_discovered_i_egg_no_ibutton[Nests.c$field_season==2016] <- Nests.c$date_discovered_i_egg_no_ibutton[Nests.c$field_season==2016] - Apr1_2016
Nests.c$last_live_check_j_egg_no_ibutton[Nests.c$field_season==2016] <- Nests.c$last_live_check_j_egg_no_ibutton[Nests.c$field_season==2016] - Apr1_2016
Nests.c$last_check_k_egg_no_ibutton[Nests.c$field_season==2016] <- Nests.c$last_check_k_egg_no_ibutton[Nests.c$field_season==2016] - Apr1_2016

#Calculating AgeDay1 values
Nests.c$AgeDay1.egg <- Nests.c$egg_age_discovery - Nests.c$date_discovered_i_egg_no_ibutton

#Setting up key name fields
names(Nests.c)[names(Nests.c)=="date_discovered_i_egg_no_ibutton"] <- "FirstFound.egg"
names(Nests.c)[names(Nests.c)=="last_live_check_j_egg_no_ibutton"] <- "LastPresent.egg"
names(Nests.c)[names(Nests.c)=="last_check_k_egg_no_ibutton"] <- "LastChecked.egg"

#Correcting success/failure differences with no iButton
Nests.c[Nests.c$nestID=="55",]$hatched <- 1 #1=failure 0=success
Nests.c[Nests.c$nestID=="129",]$Fate.nest <- 1 #1=failure 0=success
Nests.c[Nests.c$nestID=="123",]$hatched <- 1
Nests.c[Nests.c$nestID=="123",]$hatched <- 1
Nests.c[Nests.c$nestID=="142",]$Fate.nest <- 0
Nests.c[Nests.c$nestID=="147",]$hatched <- 1
Nests.c[Nests.c$nestID=="156",]$hatched <- 1
Nests.c[Nests.c$nestID=="164",]$hatched <- 1
Nests.c[Nests.c$nestID=="177",]$hatched <- 1
Nests.c[Nests.c$nestID=="189",]$hatched <- 1
Nests.c[Nests.c$nestID=="219",]$hatched <- 1
Nests.c[Nests.c$nestID=="229",]$hatched <- 1
Nests.c[Nests.c$nestID=="252",]$hatched <- 1
Nests.c[Nests.c$nestID=="254",]$hatched <- 1  #This nest would be "never returned" without the iButton data
Nests.c[Nests.c$nestID=="298",]$Fate.nest <- 1

#Removing nest 254
Nests.c <- Nests.c[Nests.c$nestID!=254,] #nestID 254 would have been "Not Revisited" if it weren't for iButton data and does not appear in coarse data


# write.csv(Nests.c, file = "Nests.coarse.csv", row.names = F)


