
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Determining the visit intervals for RWBL, DICK, & VESP ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

rm(list = ls())

#library(RMark)
#library(plotrix)
#library(beepr)
#library(ggplot2)
#library(dplyr)

#Nests from 2015&2016 that have iButtons
#Combined eggs & nestlings

#INP created from visit information only
Nests <-read.csv('Nests.coarse.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were never aged

species <- c("DICK","RWBL","VESP")
Nests <- Nests[(Nests$Species %in% species),]  #Selecting DICK, RWBL, VESP

nest.coarse <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate, Species))
nest.coarse <- droplevels(nest.coarse)

#INP created from best available information
Nests <-read.csv('Nests.fine.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[(Nests$Species %in% species),]  #Selecting DICK, RWBL, VESP

Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were never aged

nest.fine <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate, ibuttonret, Species))
nest.fine <- droplevels(nest.fine)

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Calculating average length of uncertainty period ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

nest.fine$uncertainty_period <- nest.fine$LastChecked - nest.fine$LastPresent
summary(nest.fine$uncertainty_period[nest.fine$Species=="DICK"])
summary(nest.fine$uncertainty_period[nest.fine$Species=="RWBL"])
summary(nest.fine$uncertainty_period[nest.fine$Species=="VESP"])

nest.coarse$uncertainty_period <- nest.coarse$LastChecked - nest.coarse$LastPresent
summary(nest.coarse$uncertainty_period[nest.coarse$Species=="DICK"])
summary(nest.coarse$uncertainty_period[nest.coarse$Species=="RWBL"])
summary(nest.coarse$uncertainty_period[nest.coarse$Species=="VESP"])

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Creating Visit Intervals ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

#library(dplyr)
#library(tidyr)

#rm(list = ls())
checks <- read.csv('nest.checks.csv', header=T)

#Formatting Dataset

checks$Check_Date <- as.Date(checks$Check_Date, format="%m/%d/%Y %H:%M:%S", origin = "1899-12-30")
checks$Check_Date <- as.numeric(checks$Check_Date)
Apr1_2015 <- 16526
Apr1_2016 <- Apr1_2015 + 365

checks$Check_Date[checks$Season==2015] <- checks$Check_Date[checks$Season==2015] - Apr1_2015
checks$Check_Date[checks$Season==2016] <- checks$Check_Date[checks$Season==2016] - Apr1_2016

checks <- subset(checks, select=c(NestID, Check_Date))#Select only the NestID $ Date columns
checks <- checks[order(checks$NestID, checks$Check_Date),]#Ordering Rows

#Calculate visit interval
checks$raw.int <- as.numeric(NA)

for(i in 2:nrow(checks)){
      checks$raw.int[i] <- checks$Check_Date[i] - checks$Check_Date[i-1]
}
checks$interval <- as.numeric(NA)
checks$interval[duplicated(checks$NestID)] <- checks[duplicated(checks$NestID), "raw.int"]

#Join to coarse data
names(checks)[names(checks)=="NestID"] <- "nestID"
nest.coarse <- left_join(nest.coarse, checks, by="nestID")
summary(nest.coarse$interval[nest.coarse$Species=="DICK"])
summary(nest.coarse$interval[nest.coarse$Species=="VESP"])
summary(nest.coarse$interval[nest.coarse$Species=="RWBL"])
summary(nest.coarse$interval)
sd(nest.coarse$interval, na.rm=T)

#Join to fine data
nest.fine <- left_join(nest.fine, checks, by="nestID")
nest.fine$interval[nest.fine$ibuttonret==1] <- 1 #set visit interval to 1 for all nests where the iButton was retrieved
hist(nest.fine$interval)
summary(nest.fine$interval)
summary(nest.fine$interval[nest.fine$Species=="DICK"])
summary(nest.fine$interval[nest.fine$Species=="VESP"])
summary(nest.fine$interval[nest.fine$Species=="RWBL"])

sd(nest.fine$interval, na.rm=T)
