
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Setting up working environment ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

rm(list = ls())
cleanup(ask=FALSE)

library(RMark)
#library(plotrix)
#library(beepr)
#library(ggplot2)
#library(dplyr)


#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
####             Estimating Daily Survival Rates              ####
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#


##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### RWBL DSR using coarse data ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

#Nests from 2015&2016 that have iButtons
#Egg stage only (same as simulation study)
#INP created from visit information only
Nests <-read.csv('Nests.coarse.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were never aged

Nests <- Nests[(Nests$Species=="RWBL"),]  #Selecting RWBL

nocc <- 169   #Setting Number of occassions 

coarse.RWBL <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate))

#Testing differences between real data & sim
#drops <- c(132, 468, 46, 231, 481, 20, 18, 34)
#coarse.RWBL <- coarse.RWBL[!(coarse.RWBL$NestID %in% drops),]

nn=process.data(coarse.RWBL,model="Nest",nocc=nocc, groups=c())
nn.ddl=make.design.data(nn)
run.nests=function()
{
  #~~~~~~~~~~~~~ Time Covariates ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  S.Dot.Coarse=list(formula=~1)
  #~~~~~~~~~~~~ model list & wrapper ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  cml=create.model.list("Nest")
  results=mark.wrapper(cml, data=nn, ddl=nn.ddl, adjust=F) 
  return(results)
}

RWBL.c=run.nests()

RWBL.c$S.Dot.Coarse$results$real 
RWBL.c$S.Dot.Coarse$results$n

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### RWBL DSR using fine data ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

rm(list = ls()[!ls()%in% c('RWBL.c', 'coarse.RWBL')])

#Nests from 2015&2016 that have iButtons
#Egg stage only (same as simulation study)
#INP created from best available information

Nests <-read.csv('Nests.fine.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were never aged

Nests <- Nests[(Nests$Species=="RWBL"),]  #Selecting RWBL

nocc <- 169   #Setting Number of occassions 

fine.RWBL <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate))
#Testing differences between real data & sim
#drops <- c(132, 468, 46, 231, 481, 20, 18, 34)
#fine.RWBL <- fine.RWBL[!(fine.RWBL$NestID %in% drops),]

nn=process.data(fine.RWBL,model="Nest",nocc=nocc, groups=c())
nn.ddl=make.design.data(nn)
run.nests=function()
{
  #~~~~~~~~~~~~~ Time Covariates ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  S.Dot.Fine=list(formula=~1)
  #~~~~~~~~~~~~ model list & wrapper ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  cml=create.model.list("Nest")
  results=mark.wrapper(cml, data=nn, ddl=nn.ddl, adjust=F) 
  return(results)
}

RWBL.f=run.nests()

RWBL.f$S.Dot.Fine$results$real  
RWBL.f$S.Dot.Fine$results$n

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### DICK DSR using coarse data ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

#Nests from 2015&2016 that have iButtons
#Egg stage only (same as simulation study)
#INP created from visit information only

rm(list = ls()[!ls()%in% c('RWBL.c', 'RWBL.f', 'coarse.RWBL', 'fine.RWBL')])
Nests <-read.csv('Nests.coarse.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[(Nests$Species=="DICK"),]  #Selecting DICK

Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were never aged

nocc <- 169   #Setting Number of occassions 

coarse.DICK <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate))

nn=process.data(coarse.DICK, model="Nest", nocc=nocc, groups=c())
nn.ddl=make.design.data(nn)
run.nests=function()
{
  #~~~~~~~~~~~~~ Time Covariates ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  S.Dot.Coarse=list(formula=~1)
  #~~~~~~~~~~~~ model list & wrapper ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  cml=create.model.list("Nest")
  results=mark.wrapper(cml, data=nn, ddl=nn.ddl, adjust=F) 
  return(results)
}

DICK.c=run.nests()

DICK.c$S.Dot.Coarse$results$real   
DICK.c$S.Dot.Coarse$results$n

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### DICK DSR using fine data ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

rm(list = ls()[!ls()%in% c('RWBL.c', 'RWBL.f', 'DICK.c', 'coarse.RWBL', 'fine.RWBL', 'coarse.DICK')])

#Nests from 2015&2016 that have iButtons
#Egg stage only (same as simulation study)
#INP created from best available information

Nests <-read.csv('Nests.fine.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[(Nests$Species=="DICK"),]  #Selecting DICK

Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were never aged

nocc <- 169   #Setting Number of occassions 

fine.DICK <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate))

nn=process.data(fine.DICK, model="Nest", nocc=nocc, groups=c())
nn.ddl=make.design.data(nn)
run.nests=function()
{
  #~~~~~~~~~~~~~ Time Covariates ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  S.Dot.Fine=list(formula=~1)
  #~~~~~~~~~~~~ model list & wrapper ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  cml=create.model.list("Nest")
  results=mark.wrapper(cml, data=nn, ddl=nn.ddl, adjust=F) 
  return(results)
}

DICK.f=run.nests()

DICK.f$S.Dot.Fine$results$real  
DICK.f$S.Dot.Fine$results$n

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#


##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### VESP DSR from coarse data ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

#Nests from 2015&2016 that have iButtons
#Egg stage only (same as simulation study)
#INP created from visit information only

rm(list = ls()[!ls()%in% c('RWBL.c', 'RWBL.f', 'DICK.c', 'DICK.f', 'coarse.RWBL', 'fine.RWBL', 'coarse.DICK', 'fine.DICK')])
Nests <-read.csv('Nests.coarse.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[(Nests$Species=="VESP"),]  #Selecting VESP

Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were never aged

nocc <- 169   #Setting Number of occassions 

coarse.VESP <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate))
#coarse.VESP <- coarse.VESP[coarse.VESP$NestID != 138,]#Testing differences between real data & sim

nn=process.data(coarse.VESP, model="Nest", nocc=nocc, groups=c())
nn.ddl=make.design.data(nn)
run.nests=function()
{
  #~~~~~~~~~~~~~ Time Covariates ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  S.Dot.Coarse=list(formula=~1)
  #~~~~~~~~~~~~ model list & wrapper ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  cml=create.model.list("Nest")
  results=mark.wrapper(cml, data=nn, ddl=nn.ddl, adjust=F) 
  return(results)
}

VESP.c=run.nests()

VESP.c$S.Dot.Coarse$results$real   
VESP.c$S.Dot.Coarse$results$n

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### VESP DSR from fine data ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

rm(list = ls()[!ls()%in% c('RWBL.c', 'RWBL.f', 'DICK.c', 'DICK.f', 'VESP.c', 'coarse.RWBL', 'fine.RWBL', 'coarse.DICK', 'fine.DICK', 'coarse.VESP')])

#Nests from 2015&2016 that have iButtons
#Egg stage only (same as simulation study)
#INP created from best available information

Nests <-read.csv('Nests.fine.csv', header=T)

names(Nests)[names(Nests)=="FirstFound.egg"] <- "FirstFound"
names(Nests)[names(Nests)=="LastPresent.egg"] <- "LastPresent"
names(Nests)[names(Nests)=="LastChecked.egg"] <- "LastChecked"
names(Nests)[names(Nests)=="AgeDay1.egg"] <- "AgeDay1"
names(Nests)[names(Nests)=="hatched"] <- "Fate"

Nests <- Nests[!is.na(Nests$FirstFound),] #Removing nests that were not observed with eggs or young
Nests <- Nests[(Nests$Species=="VESP"),]  #Selecting VESP

Nests <- Nests[!is.na(Nests$AgeDay1),] #Removing nests that were not observed with eggs or young

nocc <- 169   #Setting Number of occassions 

fine.VESP <- subset(Nests, select=c(nestID, FirstFound, LastPresent, LastChecked, Fate))
#fine.VESP <- fine.VESP[fine.VESP$NestID != 138,]#Testing differences between real data & sim

nn=process.data(fine.VESP, model="Nest", nocc=nocc, groups=c())
nn.ddl=make.design.data(nn)
run.nests=function()
{
  #~~~~~~~~~~~~~ Time Covariates ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  S.Dot.Fine=list(formula=~1)
  #~~~~~~~~~~~~ model list & wrapper ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  cml=create.model.list("Nest")
  results=mark.wrapper(cml, data=nn, ddl=nn.ddl, adjust=F) 
  return(results)
}

VESP.f=run.nests()

VESP.f$S.Dot.Fine$results$real  
VESP.f$S.Dot.Fine$results$n

cleanup(ask=FALSE)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
####             Analyzing Differences              ####
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#



##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Digging into differences ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

names(coarse.RWBL)[names(coarse.RWBL)=="FirstFound"] <- "FirstFound.c"
names(coarse.RWBL)[names(coarse.RWBL)=="LastPresent"] <- "LastPresent.c"
names(coarse.RWBL)[names(coarse.RWBL)=="LastChecked"] <- "LastChecked.c"
names(coarse.RWBL)[names(coarse.RWBL)=="Fate"] <- "Fate.c"
names(fine.RWBL)[names(fine.RWBL)=="FirstFound"] <- "FirstFound.f"
names(fine.RWBL)[names(fine.RWBL)=="LastPresent"] <- "LastPresent.f"
names(fine.RWBL)[names(fine.RWBL)=="LastChecked"] <- "LastChecked.f"
names(fine.RWBL)[names(fine.RWBL)=="Fate"] <- "Fate.f"
names(coarse.DICK)[names(coarse.DICK)=="FirstFound"] <- "FirstFound.c"
names(coarse.DICK)[names(coarse.DICK)=="LastPresent"] <- "LastPresent.c"
names(coarse.DICK)[names(coarse.DICK)=="LastChecked"] <- "LastChecked.c"
names(coarse.DICK)[names(coarse.DICK)=="Fate"] <- "Fate.c"
names(fine.DICK)[names(fine.DICK)=="FirstFound"] <- "FirstFound.f"
names(fine.DICK)[names(fine.DICK)=="LastPresent"] <- "LastPresent.f"
names(fine.DICK)[names(fine.DICK)=="LastChecked"] <- "LastChecked.f"
names(fine.DICK)[names(fine.DICK)=="Fate"] <- "Fate.f"
names(coarse.VESP)[names(coarse.VESP)=="FirstFound"] <- "FirstFound.c"
names(coarse.VESP)[names(coarse.VESP)=="LastPresent"] <- "LastPresent.c"
names(coarse.VESP)[names(coarse.VESP)=="LastChecked"] <- "LastChecked.c"
names(coarse.VESP)[names(coarse.VESP)=="Fate"] <- "Fate.c"
names(fine.VESP)[names(fine.VESP)=="FirstFound"] <- "FirstFound.f"
names(fine.VESP)[names(fine.VESP)=="LastPresent"] <- "LastPresent.f"
names(fine.VESP)[names(fine.VESP)=="LastChecked"] <- "LastChecked.f"
names(fine.VESP)[names(fine.VESP)=="Fate"] <- "Fate.f"

RWBL.comb <- left_join(fine.RWBL, coarse.RWBL, by="nestID")
DICK.comb <- left_join(fine.DICK, coarse.DICK, by="nestID")
VESP.comb <- left_join(fine.VESP, coarse.VESP, by="nestID")

RWBL.comb$Species <- "RWBL"
DICK.comb$Species <- "DICK"
VESP.comb$Species <- "VESP"

INP.comb <- rbind(RWBL.comb, DICK.comb, VESP.comb)

#INP.comb$period.c <- INP.comb$LastChecked.c - INP.comb$LastPresent.c
#hist(INP.comb$period.c[INP.comb$Fate.c!=0])
#summary(INP.comb$period.c[INP.comb$Fate.c!=0])
#sd(INP.comb$period.c[INP.comb$Fate.c==1], na.rm=T)

#INP.comb$period.f <- INP.comb$LastChecked.f - INP.comb$LastPresent.f
#hist(INP.comb$period.f[INP.comb$Fate.f!=0])
#summary(INP.comb$period.f[INP.comb$Fate.f!=0])
#sd(INP.comb$period.f[INP.comb$Fate.f==1], na.rm=T)

INP.comb$FirstFound.diff <- INP.comb$FirstFound.f - INP.comb$FirstFound.c
hist(INP.comb$FirstFound.diff)

INP.comb$LastPresent.diff <- INP.comb$LastPresent.f - INP.comb$LastPresent.c
hist(INP.comb$LastPresent.diff)

INP.comb$LastChecked.diff <- INP.comb$LastChecked.f - INP.comb$LastChecked.c
hist(INP.comb$LastChecked.diff)

INP.comb$df.fine <- INP.comb$LastPresent.f - INP.comb$FirstFound.f + 1
INP.comb$df.coarse <- INP.comb$LastPresent.c - INP.comb$FirstFound.c + 1
INP.comb$df.diff <- INP.comb$df.fine - INP.comb$df.coarse
hist(INP.comb$df.diff)

inflated <- INP.comb[INP.comb$LastPresent.c > INP.comb$LastPresent.f,]


model.list <- ls()
model.list <- NULL
model.list[["Dot"]] <- glm(df.diff ~ 1, family=gaussian(link='identity'), data=INP.comb)
model.list[["Species"]] <- glm(df.diff ~ Species, family=gaussian(link='identity'), data=INP.comb)

summary(model.list[["Dot"]])
summary(model.list[["Species"]])

t.test(INP.comb$FirstFound.f, INP.comb$FirstFound.c, paired=T)
t.test(INP.comb$LastPresent.f, INP.comb$LastPresent.c, paired=T)
t.test(INP.comb$LastChecked.f, INP.comb$LastChecked.c, paired=T)

t.test(INP.comb$df.fine, INP.comb$df.coarse, paired=T)

##~~~~~~~~~~~~~~~~~##
#### Cleaning Up ####
##~~~~~~~~~~~~~~~~~##

rm(list=ls())
cleanup(ask=FALSE)

