library(lme4)
library(dplyr)

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##
#### Overall iButton loss rate ####
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~##

rm(list = ls())
Nests <-read.csv('Nests.csv', header=T)

# Selecting nests enrolled in the iButton study
Nests <- Nests[which(Nests$outcome!="Failure due to human activities (note type)"),]
Nests <- Nests[Nests$AccRej!="not targeted",]
Nests.2015 <- Nests[Nests$field_season==2015,]
Nests.2015 <- Nests.2015[Nests.2015$Species=="DICK" | Nests.2015$Species=="RWBL" | Nests.2015$Species=="VESP",]
Nests.2016 <- Nests[Nests$field_season==2016,]
Nests.2016 <- Nests.2016[which(Nests.2016$ibutton_treatment_group!="NA_Deployed"),]
Nests.2016 <- Nests.2016[which(Nests.2016$ibutton_treatment_group!="NA_Not_Deployed"),]
Nests.2017 <- Nests[Nests$field_season==2017,]
Nests.2017 <- Nests.2017[Nests.2017$ibutton_treatment_group!="NA_Deployed",]
Nests.2017 <- Nests.2017[Nests.2017$ibutton_treatment_group!="NA_Not_Deployed",]
Nests <- rbind(Nests.2015, Nests.2016, Nests.2017)

rm(list=c("Nests.2015", "Nests.2016", "Nests.2017"))

# Loss rate by species or acceptor status
Nests %>%
  filter(Species %in% c("AMRO","BRTH","CHSP","GRCA","MESP", "AMGO","COYE","DICK","GRSP","LASP","NOCA","RWBL","SOSP","VESP")) %>%
  #group_by(Species) %>%
  group_by(AccRej) %>%
  summarise(deployed = sum(ibuttondep),
            retrieved = sum(ibuttonret)) %>%
  mutate(loss_rate = 1 - retrieved/deployed)


Nests <- Nests[Nests$ibuttondep==1,]
Nests$ibuttonret <- as.factor(Nests$ibuttonret)
loss.model <- glm(Nests$ibuttonret ~ Nests$AccRej, family=binomial)
summary(loss.model)

exp(cbind(coef(loss.model), confint(loss.model, level=0.95))) #Odds ratio

rm(list = ls())

